# coding: utf-8
# !/usr/bin/python

"""
Project: datascitools
Sat 18 Apr 13:04:54 2020
"""


# Author
__author__ = 'Jason Xing Zhang'
__email__ = 'jason.xing.zhang@gmail.com'
__major__ = 0
__minor__ = 0
__revision__ = 1

# Version
__version_info__ = (__major__, __minor__, __revision__)
__version__ = '{0}.{1}.{2}'.format(*__version_info__)


